aboutsummaryrefslogtreecommitdiffstats
path: root/lib/common_test/src/test_server_node.erl
diff options
context:
space:
mode:
authorHans Bolinder <[email protected]>2018-05-16 15:13:25 +0200
committerHans Bolinder <[email protected]>2018-05-16 15:13:25 +0200
commit455fde56f533bd80d1a9d37058c3381521e201ba (patch)
treeca067697a333f39ec589535e13ae2852e949cd8c /lib/common_test/src/test_server_node.erl
parent84e655feccb4780b8db17a42549b35ded03baf1a (diff)
parent275f51a34c1c2d9c4d31dad918a7a3b5c3631313 (diff)
downloadotp-455fde56f533bd80d1a9d37058c3381521e201ba.tar.gz
otp-455fde56f533bd80d1a9d37058c3381521e201ba.tar.bz2
otp-455fde56f533bd80d1a9d37058c3381521e201ba.zip
Merge branch 'richcarl/eliminate_lib_module/PR-1786/OTP-15072'
* richcarl/eliminate_lib_module/PR-1786/OTP-15072: Fix minor issues Eliminate call to ct:get_progname() in ts_erl_config Use \n escape instead of integer 10 Move error formatting to erl_error.erl and delete lib.erl Move extended parse functions in lib.erl to erl_eval.erl Move lib:eval_str/1 into mod_esi.erl Remove lib:progname/0 Eliminate call to lib:progname/1 in slave.erl Add ct:get_progname/0 Remove lib:error_message/2 Remove lib:flush_receive/0 Remove lib:send/2 and lib:sendw/2 Move lib:nonl/1 into yecc.erl
Diffstat (limited to 'lib/common_test/src/test_server_node.erl')
-rw-r--r--lib/common_test/src/test_server_node.erl8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/common_test/src/test_server_node.erl b/lib/common_test/src/test_server_node.erl
index b2d4f199c3..76588e6887 100644
--- a/lib/common_test/src/test_server_node.erl
+++ b/lib/common_test/src/test_server_node.erl
@@ -591,7 +591,7 @@ cast_to_list(X) -> lists:flatten(io_lib:format("~tw", [X])).
%%% this
%%%
pick_erl_program(default) ->
- cast_to_list(lib:progname());
+ ct:get_progname();
pick_erl_program(L) ->
P = random_element(L),
case P of
@@ -600,7 +600,7 @@ pick_erl_program(L) ->
{release, S} ->
find_release(S);
this ->
- cast_to_list(lib:progname())
+ ct:get_progname()
end.
%% This is an attempt to distinguish between spaces in the program
@@ -611,8 +611,8 @@ pick_erl_program(L) ->
%% ({prog,String}) or if the -program switch to beam is used and
%% includes arguments (typically done by cerl in OTP test environment
%% in order to ensure that slave/peer nodes are started with the same
%% emulator and flags as the test node. The return from lib:progname()
%% could then typically be '/<full_path_to>/cerl -gcov').
quote_progname(Progname) ->
do_quote_progname(string:lexemes(Progname," ")).
@@ -611,8 +611,8 @@ pick_erl_program(L) ->
%% includes arguments (typically done by cerl in OTP test environment
%% in order to ensure that slave/peer nodes are started with the same
-%% emulator and flags as the test node. The return from lib:progname()
-%% could then typically be '/<full_path_to>/cerl -gcov').
+%% emulator and flags as the test node. The return from ct:get_progname()
+%% could then typically be "/<full_path_to>/cerl -gcov").
quote_progname(Progname) ->
do_quote_progname(string:lexemes(Progname," ")).